<?php

class Brizy_Editor_API {

	const nonce = 'brizy-api';
	const AJAX_PING = 'brizy_editor_ping';
	const AJAX_GET = 'brizy_editor_get_items';
	const AJAX_UPDATE = 'brizy_update_item';
	const AJAX_GET_GLOBALS = 'brizy_get_gb';
	const AJAX_SET_GLOBALS = 'brizy_set_gb';
	const AJAX_MEDIA = 'brizy_media';
	const AJAX_SIDEBARS = 'brizy_sidebars';
	const AJAX_BUILD = 'brizy_build';
	const AJAX_SIDEBAR_CONTENT = 'brizy_sidebar_content';
	const AJAX_SHORTCODE_CONTENT = 'brizy_shortcode_content';
	const AJAX_SHORTCODE_LIST = 'brizy_shortcode_list';
	const AJAX_GET_TEMPLATES = 'brizy_get_templates';
	const AJAX_GET_INTERNAL_LINKS = 'brizy_get_internal_links';
	const AJAX_GET_POST_OBJECTS = 'brizy_get_posts';
	const AJAX_GET_MENU_LIST = 'brizy_get_menu_list';
	const AJAX_SAVE_TRIGGER = 'brizy_update_post';
	const AJAX_GET_TAXONOMIES = 'brizy_get_taxonomies';
	const AJAX_GET_TERMS = 'brizy_get_terms';
	const AJAX_JWT_TOKEN = 'brizy_multipass_create';


	const AJAX_UPDATE_MENU_DATA = 'brizy_update_menu_data';
	const AJAX_UPDATE_MENU_ITEM_DATA = 'brizy_update_menu_item_data';

	const AJAX_DOWNLOAD_MEDIA = 'brizy_download_media';
	const AJAX_MEDIA_METAKEY = 'brizy_get_media_key';

	const AJAX_SET_FEATURED_IMAGE = 'brizy_set_featured_image';
	const AJAX_SET_FEATURED_IMAGE_FOCAL_POINT = 'brizy_set_featured_image_focal_point';
	const AJAX_REMOVE_FEATURED_IMAGE = 'brizy_remove_featured_image';

	/**
	 * @var Brizy_Editor_Project
	 */
	private $project;

	/**
	 * @var Brizy_Editor_Post
	 */
	private $post;

	/**
	 * @return Brizy_Editor_Project
	 */
	public function get_project() {
		return $this->project;
	}

	/**
	 * @return Brizy_Editor_Post
	 */
	public function get_post() {
		return $this->post;
	}

	/**
	 * Brizy_Editor_API constructor.
	 *
	 * @param Brizy_Editor_Project $project
	 * @param Brizy_Editor_Post $post
	 */
	public function __construct( $project, $post ) {

		$this->project = $project;
		$this->post    = $post;

		$this->initialize();
	}

	private function initialize() {

		if ( Brizy_Editor::is_user_allowed() ) {
			add_action( 'wp_ajax_' . self::AJAX_PING, array( $this, 'ping' ) );
			add_action( 'wp_ajax_' . self::AJAX_GET, array( $this, 'get_item' ) );
			add_action( 'wp_ajax_' . self::AJAX_UPDATE, array( $this, 'update_item' ) );
			add_action( 'wp_ajax_' . self::AJAX_GET_GLOBALS, array( $this, 'get_globals' ) );
			add_action( 'wp_ajax_' . self::AJAX_SET_GLOBALS, array( $this, 'set_globals' ) );
			//add_action( 'wp_ajax_' . self::AJAX_MEDIA, array( $this, 'media' ) );
			add_action( 'wp_ajax_' . self::AJAX_SIDEBARS, array( $this, 'get_sidebars' ) );
			//add_action( 'wp_ajax_' . self::AJAX_BUILD, array( $this, 'build_content' ) );
			add_action( 'wp_ajax_' . self::AJAX_SIDEBAR_CONTENT, array( $this, 'sidebar_content' ) );
			add_action( 'wp_ajax_' . self::AJAX_SHORTCODE_CONTENT, array( $this, 'shortcode_content' ) );
			add_action( 'wp_ajax_' . self::AJAX_SHORTCODE_LIST, array( $this, 'shortcode_list' ) );
			add_action( 'wp_ajax_' . self::AJAX_GET_TEMPLATES, array( $this, 'template_list' ) );
			add_action( 'wp_ajax_' . self::AJAX_GET_INTERNAL_LINKS, array( $this, 'get_internal_links' ) );
			add_action( 'wp_ajax_' . self::AJAX_GET_POST_OBJECTS, array( $this, 'get_post_objects' ) );
			add_action( 'wp_ajax_' . self::AJAX_GET_MENU_LIST, array( $this, 'get_menu_list' ) );
			add_action( 'wp_ajax_' . self::AJAX_SAVE_TRIGGER, array( $this, 'save_trigger' ) );
			add_action( 'wp_ajax_' . self::AJAX_GET_TERMS, array( $this, 'get_terms' ) );
			add_action( 'wp_ajax_' . self::AJAX_GET_TAXONOMIES, array( $this, 'get_taxonomies' ) );
			add_action( 'wp_ajax_' . self::AJAX_DOWNLOAD_MEDIA, array( $this, 'download_media' ) );
			add_action( 'wp_ajax_' . self::AJAX_MEDIA_METAKEY, array( $this, 'get_media_key' ) );
			add_action( 'wp_ajax_' . self::AJAX_JWT_TOKEN, array( $this, 'multipass_create' ) );

//			add_action( 'wp_ajax_' . self::AJAX_GET_DEFAULT_FORM, array( $this, 'default_form' ) );
//			add_action( 'wp_ajax_' . self::AJAX_GET_FORM, array( $this, 'get_form' ) );
//			add_action( 'wp_ajax_' . self::AJAX_CREATE_FORM, array( $this, 'create_form' ) );
//			add_action( 'wp_ajax_' . self::AJAX_FORM_INTEGRATION_STATUS, array(
//				$this,
//				'update_form_integration_status'
//			) );
//			add_action( 'wp_ajax_' . self::AJAX_DELETE_FORM, array( $this, 'delete_form' ) );

			add_action( 'wp_ajax_' . self::AJAX_UPDATE_MENU_ITEM_DATA, array( $this, 'update_menu_item_data' ) );
			add_action( 'wp_ajax_' . self::AJAX_UPDATE_MENU_DATA, array( $this, 'update_menu_data' ) );
			add_action( 'wp_ajax_' . self::AJAX_SET_FEATURED_IMAGE, array( $this, 'set_featured_image' ) );
			add_action( 'wp_ajax_' . self::AJAX_SET_FEATURED_IMAGE_FOCAL_POINT, array(
				$this,
				'set_featured_image_focal_point'
			) );
			add_action( 'wp_ajax_' . self::AJAX_REMOVE_FEATURED_IMAGE, array( $this, 'remove_featured_image' ) );

		}

//		add_action( 'wp_ajax_' . self::AJAX_SUBMIT_FORM, array( $this, 'submit_form' ) );
//		add_action( 'wp_ajax_nopriv_' . self::AJAX_SUBMIT_FORM, array( $this, 'submit_form' ) );
	}

	public function update_menu_item_data() {
		if ( ! isset( $_POST['menuItemId'] ) || get_post_type( $_POST['menuItemId'] ) != 'nav_menu_item' ) {
			$this->error( 400, 'Unknown menu item' );
		}

		$json_decode = json_decode( stripslashes( $_POST['menuItemData'] ) );

		if ( ! isset( $_POST['menuItemData'] ) || is_null( $json_decode ) ) {
			$this->error( 400, 'Bad request' );
		}

		$menuItems = get_posts( array(
			'meta_key'   => 'brizy_post_uid',
			'meta_value' => $_POST['menuItemId'],
			'post_type'  => 'nav_menu_item',
		) );

		if ( count( $menuItems ) == 0 ) {
			$this->error( 400, 'Unknown menu item' );;
		}

		$menu = $menuItems[0];

		update_post_meta( (int) $menu->ID, 'brizy_data', $json_decode );

		$this->success( array() );
	}

	public function update_menu_data() {
		if ( ! isset( $_POST['menuId'] ) ) {
			$this->error( 400, 'Unknown menu' );
		}

		$json_decode = json_decode( stripslashes( $_POST['menuData'] ) );

		if ( ! isset( $_POST['menuData'] ) || is_null( $json_decode ) ) {
			$this->error( 400, 'Bad request' );
		}


		$menu = get_terms( array(
			'taxonomy'   => 'nav_menu',
			'hide_empty' => false,
			'meta_query' => array(
				'relation' => 'AND',
				array(
					'key'     => 'brizy_uid',
					'value'   => $_POST['menuId'],
					'compare' => '='
				)
			)
		) );


		if ( isset( $menu[0] ) ) {
			$menu = $menu[0];
		} else {
			$this->error( 400, 'Unknown menu item' );
		}
		update_term_meta( (int) $menu->term_id, 'brizy_data', $json_decode );

		$this->success( array() );
	}

	public function set_featured_image() {
		$this->authorize();

		if ( ! isset( $_REQUEST['attachmentId'] ) ) {
			$this->error( 400, 'Bad request' );
		}

		if ( $this->post && $this->post->uses_editor() ) {
			set_post_thumbnail( $this->post->get_id(), (int) $_REQUEST['attachmentId'] );

			$uid = $this->createMediaKey( $this->post->get_id(), (int) $_REQUEST['attachmentId'] );

			$this->success( array( 'uid' => $uid ) );
		}

		$this->error( 400, 'Invalid post' );
	}

	public function set_featured_image_focal_point() {
		if ( ! isset( $_REQUEST['attachmentId'] ) || ! isset( $_REQUEST['pointX'] ) || ! isset( $_REQUEST['pointY'] ) ) {
			$this->error( 400, 'Bad request' );
		}

		if ( $this->post && $this->post->uses_editor() ) {

			update_post_meta( $this->post->get_id(), 'brizy_attachment_focal_point', array(
				'x' => $_REQUEST['pointX'],
				'y' => $_REQUEST['pointY']
			) );

			$this->success( array() );
		}

		$this->error( 400, 'Invalid post' );
	}

	public function remove_featured_image() {
		$this->authorize();

		if ( $this->post && $this->post->uses_editor() ) {
			delete_post_thumbnail( $this->post->get_id() );
			delete_post_meta( $this->post->get_id(), 'brizy_attachment_focal_point' );
			$this->success( null );
		}

		$this->error( 400, 'Invalid post' );
	}


	public function multipass_create() {

		try {
			$client_id = $_REQUEST['client_id'];

			if ( ! $client_id ) {
				throw new Exception( 'Bad request' );
			}

//			$platform = new Brizy_Editor_API_Platform();
//			if ( $platform->isUserCreatedLocally() ) {
//				$platform->createUser( null, false );
//			}

			$user = Brizy_Editor_User::get();

			if ( ! $user ) {
				throw new Exception( "Unable to create user" );
			}

			$email               = $user->getPlatformUserEmail();
			$secret              = $user->getPlatformUserSignature();
			$platformCredentials = Brizy_Editor_API_Platform::getCredentials();
			$urlBuilder          = new Brizy_Editor_UrlBuilder( Brizy_Editor_Project::get() );

			$platform_client_id = $platformCredentials->client_id;

			date_default_timezone_set( "UTC" );

			$date = new \DateTime();

			$user_data = array(
				"user_id"    => $user->getPlatformUserId(),
				"created_at" => $date->format( DateTime::ISO8601 ),
				'client_id'  => $client_id
			);

			$multipass = new Brizy_Editor_Multipass( $secret );

			$token = $multipass->encode( $user_data );

			$redirect_uri = sprintf( Brizy_Config::getEditorBaseUrls() . Brizy_Config::BRIZY_PLATFORM_MULTIPASS_LOGIN, $platform_client_id, $token, $email );

			wp_redirect( $redirect_uri );
			exit;
		} catch ( Exception $exception ) {
			Brizy_Logger::instance()->exception( $exception );
			$this->error( 500, "Bad request" );
			exit;
		}
	}


	/**
	 * @internal
	 **/
	public function ping() {
		try {
			$this->authorize();
			$this->success( array() );
		} catch ( Exception $exception ) {
			Brizy_Logger::instance()->exception( $exception );
			$this->error( $exception->getCode(), $exception->getMessage() );
			exit;
		}
	}

	/**
	 * @internal
	 **/
	public function get_globals() {
		try {
			$this->authorize();
			$data = $this->create_post_globals();

			$this->success( $data );
		} catch ( Exception $exception ) {
			Brizy_Logger::instance()->exception( $exception );
			$this->error( $exception->getCode(), $exception->getMessage() );
			exit;
		}
	}

	/**
	 * @internal
	 */
	public function set_globals() {
		try {
			$this->authorize();

			// update project globas
			$data = stripslashes( $this->param( 'gb' ) );

			// let's try to validate the global data
			// by deserializing and checking the project and globals properties
			$jsonData = json_decode( $data );
			if ( is_null( $jsonData ) ) {
				throw new Exception( "The received global json cannot be decoded" );
			}
			if ( ! is_object( $jsonData ) || ! isset( $jsonData->project ) || ! isset( $jsonData->language ) ) {
				throw new Exception( "The received global data is invalid" );
			}


			//$post_id = (int) $this->param( 'post' );
			$this->project->setGlobalsAsJson( $data );

			// mark all brizy post to be compiled on next view
			Brizy_Editor_Post::clear_compiled_cache();

			// return the project data
			$this->success( $this->create_post_globals() );
		} catch ( Exception $exception ) {
			Brizy_Logger::instance()->exception( $exception );
			$this->error( $exception->getCode(), $exception->getMessage() );
			exit;
		}
	}

	/**
	 * @internal
	 **/
	public function get_item() {
		try {
			$this->authorize();
			$post_arr             = self::create_post_arr( $this->post );
			$post_arr['is_index'] = true; // this is for the case when the page we return is not an index page.. but the editor wants one.
			$this->success( array( $post_arr ) );
		} catch ( Exception $exception ) {
			Brizy_Logger::instance()->exception( $exception );
			$this->error( 500, $exception->getMessage() );
			exit;
		}
	}

	/**
	 * @internal
	 **/
	public function update_item() {
		try {
			$data      = stripslashes( $this->param( 'data' ) );
			$atemplate = $this->param( 'template' );

			if ( $atemplate ) {
				$this->post->set_template( $atemplate );
			}

			if ( $data ) {
				$this->post->set_editor_data( $data );
				$this->post->set_editor_version( BRIZY_EDITOR_VERSION );
			}

			if ( $this->param( 'compile' ) ) {
				$this->post->compile_page();
			}

			$this->post->save();

			$this->success( self::create_post_arr( $this->post ) );
		} catch ( Exception $exception ) {
			Brizy_Logger::instance()->exception( $exception );
			$this->error( $exception->getCode(), $exception->getMessage() );
		}
	}

	public function save_trigger() {
		try {
			$this->authorize();
			//$post_id = $this->param( 'post' );
			//$post    = Brizy_Editor_Post::get( $post_id );

			if ( ! $this->post->uses_editor() ) {
				return;
			}
			$post_type        = $this->post->get_wp_post()->post_type;
			$post_type_object = get_post_type_object( $post_type );
			$can_publish      = current_user_can( $post_type_object->cap->publish_posts );
			$post_status      = $can_publish ? 'publish' : 'pending';

			// compilation needs to go here
			//$post->compile_page();
			$this->post->save();

			$brizy_compiled_page = $this->post->get_compiled_page();

			wp_update_post( array(
				'ID'           => $this->post->get_parent_id(),
				'post_status'  => $post_status,
				'post_content' => $brizy_compiled_page->get_body()
			) );

			// get latest version of post
			$post                 = Brizy_Editor_Post::get( $this->post->get_parent_id() );
			$post_arr             = self::create_post_arr( $post );
			$post_arr['is_index'] = true; // this is for the case when the page we return is not an index page.. but the editor wants one.
			$this->success( array( $post_arr ) );

		} catch ( Exception $exception ) {
			Brizy_Logger::instance()->exception( $exception );
			$this->error( 500, "Invalid post id" );
			exit;
		}
	}


	public function sidebar_content() {
		try {

			if ( isset( $_REQUEST['sidebarId'] ) ) {
				$sidebar_id = $_REQUEST['sidebarId'];
			} else {
				throw new Exception( 'Invalid sidebar id provided', 500 );
			}

			ob_start();

			dynamic_sidebar( $sidebar_id );

			$sidebar_html = ob_get_clean();

			$this->success( array(
				'sidebarId'      => $sidebar_id,
				'sidebarContent' => $sidebar_html
			) );
		} catch ( Exception $exception ) {
			Brizy_Logger::instance()->exception( $exception );
			$this->error( $exception->getCode(), $exception->getMessage() );
		}
	}

	public function shortcode_content() {
		try {

			if ( isset( $_REQUEST['shortcode'] ) ) {
				$shortcode = stripslashes( $_REQUEST['shortcode'] );
			} else {
				throw new Exception( 'Shortcode string not provided.', 500 );
			}
			$shortcode_content = do_shortcode( $shortcode );

			$this->success( array(
				'shortcode' => $shortcode_content
			) );
		} catch ( Exception $exception ) {
			Brizy_Logger::instance()->exception( $exception );
			$this->error( $exception->getCode(), $exception->getMessage() );
		}
	}

	public function shortcode_list() {
		try {
			global $shortcode_tags;
			$this->success( array_keys( $shortcode_tags ) );
		} catch ( Exception $exception ) {
			Brizy_Logger::instance()->exception( $exception );
			$this->error( $exception->getCode(), $exception->getMessage() );
		}
	}

	public function template_list() {
		try {
			$templates = get_page_templates();

			$response = array(
				(object) array( "name" => 'Default', 'value' => 'default' )
			);

			foreach ( $templates as $name => $path ) {
				$response[] = (object) array( "name" => $name, 'value' => $path );
			}

			$this->success( $response );
		} catch ( Exception $exception ) {
			Brizy_Logger::instance()->exception( $exception );
			$this->error( $exception->getCode(), $exception->getMessage() );
		}
	}

	public function get_post_objects() {

		global $wp_post_types;

		$searchTerm      = $this->param( 'filterTerm' );
		$postType        = $this->param( 'postType' ) ? $this->param( 'postType' ) : null;
		$excludePostType = $this->param( 'excludePostTypes' ) ? $this->param( 'excludePostTypes' ) : array();

		if ( ! $postType ) {
			$postType = array_keys( array_filter( $wp_post_types, function ( $type ) {
				return ! in_array( $type->name, array( 'brizy_template' ) ) && $type->show_ui;
			} ) );
		}


		$posts = $this->get_post_list( $searchTerm, $postType, $excludePostType );

		wp_send_json( array( 'filter_term' => $searchTerm, 'posts' => $posts ), 200 );
	}

	public function get_internal_links() {

		$search_term = $this->param( 'filter_term' );

		$links = array();
		$links = array_merge( $links, $this->get_post_link_list( $search_term ) );
		$links = array_merge( $links, $this->get_term_link_list( $search_term ) );
		$links = array_merge( $links, $this->get_author_link_list( $search_term ) );

		wp_send_json( array( 'filter_term' => $search_term, 'links' => $links ), 200 );
	}

	public function get_sidebars() {
		global $wp_registered_sidebars;

		$items = array();

		foreach ( $wp_registered_sidebars as $sidebar ) {
			$item    = array(
				'id'    => $sidebar['id'],
				'title' => $sidebar['name'],
			);
			$items[] = $item;
		}

		$this->success( $items );
	}

	protected function param( $name ) {
		if ( isset( $_REQUEST[ $name ] ) ) {
			return $_REQUEST[ $name ];
		}

		return null;
	}

	protected function error( $code, $message ) {
		wp_send_json_error( array( 'code' => $code, 'message' => $message ), $code );
	}

	protected function success( $data ) {
		wp_send_json( $data );
	}

	protected function static_url() {
		return Brizy_Editor::get()->get_url( '/includes/editor/static' );
	}

	private function authorize() {
		if ( ! wp_verify_nonce( $_REQUEST['hash'], self::nonce ) ) {
			wp_send_json_error( array( 'code' => 400, 'message' => 'Bad request' ), 400 );
		}
	}

	public static function create_post_arr( Brizy_Editor_Post $post ) {

		$p_id      = (int) $post->get_id();
		$the_title = get_the_title( $p_id );

		$global = array(
			'title'    => $the_title,
			'slug'     => sanitize_title( $the_title ),
			'data'     => $post->get_editor_data(),
			'id'       => $p_id,
			'is_index' => false,
			'template' => get_page_template_slug( $p_id ),
			'status'   => get_post_status( $p_id ),
			'url'      => get_the_permalink( $p_id )
		);

		return $global;
	}

	/**
	 * @return array
	 */
	public function create_post_globals() {
		$wp_post = $this->post->get_wp_post();

		$globals = array(
			'id'        => $this->project->getId(),
			'gb'        => $this->project->getGlobals(),
			'name'      => $wp_post->post_name,
			'createdAt' => $wp_post->post_date,
			'updatedAt' => $wp_post->post_date,
			'user'      => array(
				'email' => null,
				'id'    => null,
			),
		);

		return $globals;
	}

	/**
	 * Return an array of terms
	 *
	 * Ex: ['label'=>'Term name',
	 *      'url'=>'term url',
	 *      'taxonomy'=>'taxonomy name']
	 *
	 *
	 * @param $search_term
	 *
	 * @return array
	 */
	private function get_term_link_list( $search_term ) {

		$links = array();

		$args = array();

		if ( $search_term ) {
			$args['name__like'] = $search_term;
		}

		$terms = get_terms( $args );

		foreach ( $terms as $term ) {
			$links[] = (object) array(
				'label'    => $term->name,
				'url'      => get_term_link( $term ),
				'taxonomy' => $term->taxonomy
			);
		}

		return $links;
	}

	private function get_author_link_list( $search_term ) {
		$authors = get_users( array( 'name_like' => $search_term ) );
		$links   = array();
		foreach ( $authors as $user ) {
			$user_nicename = $user->user_nicename;
			if ( stripos( $user_nicename, $search_term ) !== false ) {
				$links[] = (object) array(
					'label'  => $user_nicename,
					'url'    => get_author_posts_url( $user->ID ),
					'author' => true
				);
			}
		}

		return $links;
	}

	/**
	 * @param $search_term
	 *
	 * @return array
	 */
	private function get_post_link_list( $search_term ) {

		add_filter( 'posts_where', array( $this, 'brizy_post_title_filter' ), 10, 2 );

		$post_query = array(
			'post_type'      => Brizy_Editor::get()->supported_post_types(),
			'posts_per_page' => - 1,
			'post_status'    => 'publish',
			'orderby'        => 'post_title',
			'order'          => 'ASC'
		);

		if ( $search_term ) {
			$post_query['post_title_term'] = $search_term;
		}

		$posts = new WP_Query( $post_query );

		$links = array();

		foreach ( $posts->posts as $post ) {
			$permalink = null;
			switch ( $post->post_type ) {
				case 'revision':
				case 'nav_menu_item':
					continue 2;
				case 'page':
					$permalink = get_page_link( $post->ID );
					break;
				case 'post':
					$permalink = get_permalink( $post->ID );
					break;
				case 'attachment':
					$permalink = get_attachment_link( $post->ID );
					break;
				default:
					$permalink = get_post_permalink( $post->ID );
					break;
			}

			$label = get_the_title( $post );

			$links[] = (object) array( 'label' => $label, 'url' => $permalink, 'post_type' => $post->post_type );
		}

		remove_filter( 'posts_where', 'brizy_post_title_filter', 10 );

		return $links;
	}

	public function get_post_list( $searchTerm, $postType, $excludePostType = array() ) {

		global $wp_post_types;

		add_filter( 'posts_where', array( $this, 'brizy_post_title_filter' ), 10, 2 );

		$post_query = array(
			'post_type'      => $postType,
			'posts_per_page' => - 1,
			'post_status'    => $postType == 'attachment' ? 'inherit' : 'publish',
			'orderby'        => 'post_title',
			'order'          => 'ASC'
		);

		if ( $searchTerm ) {
			$post_query['post_title_term'] = $searchTerm;
		}

		$posts = new WP_Query( $post_query );

		$result = array();

		foreach ( $posts->posts as $post ) {

			if ( in_array( $post->post_type, $excludePostType ) ) {
				continue;
			}

			$result[] = (object) array(
				'ID'              => $post->ID,
				'post_type'       => $post->post_type,
				'post_type_label' => $wp_post_types[ $post->post_type ]->label,
				'title'           => apply_filters( 'the_title', $post->post_title )
			);
		}

		remove_filter( 'posts_where', 'brizy_post_title_filter', 10 );

		return $result;
	}

	public function brizy_post_title_filter( $where, $wp_query = null ) {

		global $wpdb;


		if ( $wp_query instanceof WP_Query && $term = $wp_query->get( 'post_title_term' ) ) {
			$search_term = $wpdb->esc_like( $term );
			$search_term = ' \'%' . $search_term . '%\'';

			$where .= ' AND ' . $wpdb->posts . '.post_title LIKE ' . $search_term;
		}

		return $where;
	}


	public function get_menu_list() {
		wp_send_json( wp_get_nav_menus( array( 'hide_empty' => true ) ), 200 );
	}

	/**
	 * Used in woocomerce producs shortcode in editor
	 */
	public function get_terms() {

		try {
			$taxonomy = $this->param( 'taxonomy' );

			$terms = (array) get_terms( array( 'taxonomy' => $taxonomy, 'hide_empty' => false ) );

			wp_send_json( array_values( $terms ) );
		} catch ( Exception $e ) {
			wp_send_json_error( array(), 500 );
		}
	}

	public function get_taxonomies() {

		try {
			$terms = get_taxonomies( array( 'public' => true, 'show_ui' => true ), 'objects' );

			wp_send_json( array_values( array_filter( $terms, function ( $term ) {
				return $term;
			} ) ) );
		} catch ( Exception $e ) {
			wp_send_json_error( array(), 500 );
		}
	}


	public function download_media() {
		try {
			$project = Brizy_Editor_Project::get();
			$apost   = (int) $_REQUEST['post_id'];
			$post    = Brizy_Editor_Post::get( $apost );

			$media_cacher = new Brizy_Editor_CropCacheMedia( $project, $post->get_parent_id() );
			$media_cacher->download_original_image( $_REQUEST['media'] );

			wp_send_json( array(), 200 );
		} catch ( Exception $e ) {
			wp_send_json_error( array(), 500 );
		}
	}

	public function get_media_key() {
		try {
			$apost         = (int) $_REQUEST['post_id'];
			$attachment_id = (int) $_REQUEST['attachment_id'];

			if ( ! $attachment_id ) {
				$this->error( 400, 'Invalid attachment id' );
			}

			$uid = $this->createMediaKey( $apost, $attachment_id );

			$this->success( array( 'uid' => $uid ) );

		} catch ( Exception $E ) {
			return;
		}
	}


	private function createMediaKey( $postId, $attachmentId ) {
		$uid = get_post_meta( $attachmentId, 'brizy_attachment_uid', true );

		if ( ! $uid ) {
			$uid = "wp-" . md5( $attachmentId . time() );
			update_post_meta( $attachmentId, 'brizy_attachment_uid', $uid );
		}

		if ( $postId ) {
			$post    = Brizy_Editor_Post::get( $postId );
			$post_ui = $post->get_uid();

			$post_uids = get_post_meta( $attachmentId, 'brizy_post_uid' );

			if ( ! in_array( $post_ui, $post_uids ) ) {
				add_post_meta( $attachmentId, 'brizy_post_uid', $post_ui );
			}
		}

		return $uid;
	}
}